@@ -27,6 +27,7 @@ from hledger_utils.utils import (
     handle_keyboardinterrupt,
     handle_exception,
 )
+from hledger_utils.version import __version__
 
 # external modules
 import pandas as pd
@@ -146,8 +147,9 @@ Usage: Replace 'hledger' in your command with 'hledger-plot' or 'hledger plot --
 hledger balance -M Costs
       ⮕  hledger plot -- balance -M Costs (double-dash after 'hledger plot')
       ⮕  hledger-plot    balance -M Costs (invoking hledger-plot directly, no double-dash)
-      ⮕  hledger plot    balance -M Costs (only works without 'hledger-plot'-specific options)
+      ⮕  hledger plot    balance -M Costs (only works without 'hle (version f"{__version__})dger-plot'-specific options)
 
+version {version}, written by Yann Büchau, source code is at https://gitlab.com/nobodyinperson/hledger-utils
 """.strip(),
     formatter_class=argparse.RawDescriptionHelpFormatter,
     epilog="""
@@ -175,6 +177,9 @@ hledger balance -M Costs
 Written by Yann Büchau
 """.strip(),
 )
+parser.add_argument(
+    "-V", "--version", action="version", version=f"%(prog)s {__version__}"
+)
 parser.add_argument(
     "-o",
     "--output",
@@ -187,6 +192,11 @@ parser.add_argument(
 parser.add_argument(
     "--no-show", help="don't show the plot", action="store_true"
 )
+parser.add_argument(
+    "--terminal",
+    help="Plot in terminal (with drawilleplot)",
+    action="store_true",
+)
 parser.add_argument(
     "-v",
     "--verbose",
@@ -645,6 +655,9 @@ def cli(cli_args=sys.argv[1:]):
     )
     logger.debug(f"data = \n{data}")
 
+    if args.terminal:
+        matplotlib.use("module://drawilleplot")
+
     # some sane defaults for rcParams
     plt.rcParams["legend.handlelength"] = 5
     if len(data.columns) > 10:
@@ -795,7 +808,7 @@ def cli(cli_args=sys.argv[1:]):
                 logger.debug(
                     f"data after {modname!r} with steps {modsteps}:\n{data}"
                 )
-            else:
+            elif index is not None:
                 logger.warning(f"No {modname!r} steps? ({index = })")
         else:
             logger.warning(
@@ -879,6 +892,10 @@ def cli(cli_args=sys.argv[1:]):
         fig.autofmt_xdate()
 
         for output_file in flatten(args.output):
+            logger.info(
+                f"Saving plots with --terminal active "
+                f"might result in {output_file!r} looking weird."
+            )
             logger.info("📥  Saving plot to '{}'".format(output_file))
             if output_file.endswith(".pickle"):
                 with open(output_file, "wb") as fh:
